@@ -26,17 +26,20 @@
  *
 \*---------------------------------------------------------------------------*/
 
-#include <pcmcia/config.h>
-#include <pcmcia/k_compat.h>
-
+#include <asm/io.h>
+#include <asm/system.h>
+#include <linux/module.h>
 #include <linux/kernel.h>
 #include <linux/sched.h>
 #include <linux/ptrace.h>
-#include <linux/malloc.h>
 #include <linux/string.h>
 #include <linux/timer.h>
-#include <asm/io.h>
-#include <asm/system.h>
+#include <linux/version.h>
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,4,18)
+#include <linux/malloc.h>
+#else
+#include <linux/slab.h>
+#endif
 
 #include <pcmcia/version.h>
 #include <pcmcia/cs_types.h>
@@ -47,6 +50,13 @@
 #include <linux/skbuff.h>
 #include <linux/capi.h>
 
+#if defined (MODULE_LICENSE)
+MODULE_LICENSE ("GPL");
+#endif
+#if defined (MODULE_DESCRIPTION)
+MODULE_DESCRIPTION ("FRITZ!Card PCMCIA CS Module");
+#endif
+
 /*---------------------------------------------------------------------------*\
  * All the PCMCIA modules use PCMCIA_DEBUG to control debugging.  If you do 
  * not define PCMCIA_DEBUG at all, all the debug code will be left out.  If 
@@ -491,7 +501,7 @@ static int fcpcmcia_event (event_t event, int priority,
     case CS_EVENT_CARD_REMOVAL:
 	link->state &= ~DEV_PRESENT;
 	if (link->state & DEV_CONFIG) {
-	    link->release.expires = RUN_AT (HZ/20);
+	    link->release.expires = jiffies + (HZ/20);
 	    add_timer (&link->release);
 	}
 	break;
