@@ -53,7 +53,7 @@ extern __inline__ int atomic_inc_and_test_greater_zero (volatile atomic_t *v)
 
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/
-#ifndef NDEBUG
+#if !defined (NDEBUG)
 # define assert(x)	(!(x)?message("%s(%d): assert (%s) failed\n", \
                                         __FILE__, __LINE__, #x):((void)0))
 # define info(x)	(!(x)?message("%s(%d): info (%s) failed\n", \
@@ -72,7 +72,7 @@ extern void vlprintf (const char * level, const char * fmt, va_list args);
 
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/
-#ifndef NDEBUG
+#if !defined (NDEBUG)
 extern unsigned hallocated (void);
 extern unsigned hallocator (void * mem);
 extern int	hvalid (void * mem);
@@ -83,6 +83,59 @@ extern void *   hcalloc (unsigned size);
 
 extern void     hfree (void * mem);
 
+/*---------------------------------------------------------------------------*\
+\*---------------------------------------------------------------------------*/
+extern unsigned libheap_init (unsigned heap_size);
+extern void libheap_exit (void);
+
+/*---------------------------------------------------------------------------*\
+\*---------------------------------------------------------------------------*/
+#if !defined (NDEBUG) && defined (LOG_TIMER)
+
+#include <linux/time.h>
+
+typedef struct {
+
+	const char *	name;
+	struct timeval	t;
+	struct timeval	d;
+} dbg_timer;
+
+#define	PRINT_TIMER(x)		log ( \
+					"Timer '%s': %ld s, %ld s\n", \
+					(x)->name, \
+					(x)->t.tv_sec, (x)->t.tv_usec \
+				)
+#define	PRINT_TIME_MSG(s,x)	log ( \
+					"%s: %ld s, %ld s\n", \
+					s, (x)->t.tv_sec, (x)->t.tv_usec \
+				)
+
+#define	WATCH_DECL(id)		dbg_timer	id##_timer
+#define	WATCH_START(id)		start_watch (&id##_timer)
+#define	WATCH_STOP(id)		stop_watch (&id##_timer); \
+				PRINT_TIME_MSG(#id,&id##_timer)
+	
+/*---------------------------------------------------------------------------*\
+\*---------------------------------------------------------------------------*/
+extern int	timers_start (void);
+extern void	timers_stop (void);
+
+/*---------------------------------------------------------------------------*\
+\*---------------------------------------------------------------------------*/
+extern void	setup_timer (dbg_timer * t, long dsec, long dusec);
+extern int	check_timer (dbg_timer * t);
+extern void	touch_timer (dbg_timer * t);
+
+extern void	start_watch (dbg_timer * w);
+extern void	stop_watch (dbg_timer * w);
+#else
+#define	PRINT_TIMER(t)
+#define	WATCH_DECL(name)
+#define	WATCH_START(name)
+#define	WATCH_STOP(name)
+#endif
+
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/
 #ifdef NEED_MEM_STR_PROTOS
